@@ -1,13 +1,13 @@
-## ----include = FALSE----------------------------------------------------------
+## ----include = FALSE, message=FALSE-------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  install.packages("cnmap")
+# install.packages("cnmap")
 
-## -----------------------------------------------------------------------------
+## ----dpi=150------------------------------------------------------------------
 library(ggplot2)
 library(sf)
 library(cnmap)
@@ -23,6 +23,16 @@ ggplot(data = map2) + geom_sf()
 map3 <- getMap(name = "吉林省", subRegion = TRUE)
 ggplot(data = map3) + geom_sf()
 
+map3 <- getMap(name = "吉林省", subRegion = TRUE)
+head(map3)
+ggplot(data = map3) + 
+  geom_sf() +
+  geom_sf_label(aes(label = name))
+
+ggplot(data = map3) + 
+  geom_sf(aes(fill = name)) +
+  geom_sf_label(aes(label = name))
+
 ## -----------------------------------------------------------------------------
 map4 <- getMap(name = "长春市", subRegion = TRUE)
 ggplot(data = map4) + geom_sf()
